==> ml-pnet-0.6.8.tar.gz: ml-pnet-0.6.8/mcs-sources/class/System.Data/System.Data.Sql/ISqlCommand.cs <==
//
// System.Data.Sql.ISqlCommand
//
// Author:
//   Tim Coleman (tim@timcoleman.com)
//
// Copyright (C) Tim Coleman, 2003
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Xml;

namespace System.Data.Sql {
	public interface ISqlCommand : IDbCommand, IDisposable
	{
		#region Properties

		ISqlConnection Connection { get; set; }
		SqlNotificationRequest Notification { get; set; }
		ISqlParameterCollection Parameters { get; }
		ISqlTransaction Transaction { get; set; }

		#endregion // Properties

		#region Methods

		ISqlParameter CreateParameter ();

		ISqlReader ExecutePageReader (CommandBehavior behavior, int startRow, int pageSize);
		ISqlReader ExecuteReader ();
		ISqlReader ExecuteReader (CommandBehavior behavior);
 		ISqlResultSet ExecuteResultSet (ResultSetOptions options);
		ISqlResultSet ExecuteResultSet (ResultSetOptions options, string cursorname);
		ISqlRecord ExecuteRow ();
		object ExecuteSqlScalar ();
		XmlReader ExecuteXmlReader ();

		#endregion // Methods
	}
}

#endif

==> ml-pnet-0.6.12.tar.gz: ml-pnet-0.6.12/mcs-sources/class/System.Data/System.Data.Sql/ISqlCommand.cs <==
//
// System.Data.Sql.ISqlCommand
//
// Author:
//   Tim Coleman (tim@timcoleman.com)
//
// Copyright (C) Tim Coleman, 2003
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Xml;

namespace System.Data.Sql {
	public interface ISqlCommand : IDbCommand, IDisposable
	{
		#region Properties

		ISqlConnection Connection { get; }
		SqlNotificationRequest Notification { get; set; }
		ISqlParameterCollection Parameters { get; }
		ISqlTransaction Transaction { get; set; }

		#endregion // Properties

		#region Methods

		ISqlParameter CreateParameter ();
		ISqlReader ExecutePageReader (CommandBehavior behavior, int startRow, int pageSize);
		ISqlReader ExecuteReader ();
		ISqlReader ExecuteReader (CommandBehavior behavior);
		ISqlResultSet ExecuteResultSet (ResultSetOptions options);
		ISqlResultSet ExecuteResultSet (ResultSetOptions options, string cursorname);
		ISqlRecord ExecuteRow ();
		object ExecuteSqlScalar ();
		XmlReader ExecuteXmlReader ();

		#endregion // Methods
	}
}

#endif
